@@ -1,4 +1,4 @@
-# flake8: NOQA W605
+# flake8: NOQA: W605
 """Pythonization of the :ref:`tmux(1)` pane.
 
 libtmux.pane
@@ -17,8 +17,6 @@ from libtmux.neo import Obj, fetch_obj
 from . import exc
 
 if t.TYPE_CHECKING:
-    from typing_extensions import Literal
-
     from .server import Server
     from .session import Session
     from .window import Window
@@ -29,8 +27,7 @@ logger = logging.getLogger(__name__)
 
 @dataclasses.dataclass()
 class Pane(Obj):
-    """
-    A :term:`tmux(1)` :term:`Pane` [pane_manual]_.
+    """:term:`tmux(1)` :term:`Pane` [pane_manual]_.
 
     ``Pane`` instances can send commands directly to a pane, or traverse
     between linked tmux objects.
@@ -55,13 +52,11 @@ class Pane(Obj):
 
     Notes
     -----
-
     .. versionchanged:: 0.8
         Renamed from ``.tmux`` to ``.cmd``.
 
     References
     ----------
-
     .. [pane_manual] tmux pane. openbsd manpage for TMUX(1).
            "Each window displayed by tmux may be split into one or more
            panes; each pane takes up a certain area of the display and is
@@ -74,11 +69,13 @@ class Pane(Obj):
     server: "Server"
 
     def refresh(self) -> None:
+        """Refresh pane attributes from tmux."""
         assert isinstance(self.pane_id, str)
         return super()._refresh(obj_key="pane_id", obj_id=self.pane_id)
 
     @classmethod
     def from_pane_id(cls, server: "Server", pane_id: str) -> "Pane":
+        """Create Pane from existing pane_id."""
         pane = fetch_obj(
             obj_key="pane_id",
             obj_id=pane_id,
@@ -93,6 +90,7 @@ class Pane(Obj):
     #
     @property
     def window(self) -> "Window":
+        """Parent window of pane."""
         assert isinstance(self.window_id, str)
         from libtmux.window import Window
 
@@ -100,12 +98,15 @@ class Pane(Obj):
 
     @property
     def session(self) -> "Session":
+        """Parent session of pane."""
         return self.window.session
 
-    #
-    #
+    """
+    Commands (pane-scoped)
+    """
+
     def cmd(self, cmd: str, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """Return :meth:`Server.cmd` defaulting to ``target_pane`` as target.
+        """Execute tmux subcommand against target pane. See also: :meth:`Server.cmd`.
 
         Send command to tmux with :attr:`pane_id` as ``target-pane``.
 
@@ -117,11 +118,12 @@ class Pane(Obj):
 
         return self.server.cmd(cmd, *args, **kwargs)
 
-    #
-    #
+    """
+    Commands (tmux-like)
+    """
+
     def resize_pane(self, *args: t.Any, **kwargs: t.Any) -> "Pane":
-        """
-        ``$ tmux resize-pane`` of pane and return ``self``.
+        """Resize tmux pane.
 
         Parameters
         ----------
@@ -154,11 +156,10 @@ class Pane(Obj):
 
     def capture_pane(
         self,
-        start: t.Union["Literal['-']", t.Optional[int]] = None,
-        end: t.Union["Literal['-']", t.Optional[int]] = None,
+        start: t.Union["t.Literal['-']", t.Optional[int]] = None,
+        end: t.Union["t.Literal['-']", t.Optional[int]] = None,
     ) -> t.Union[str, t.List[str]]:
-        """
-        Capture text from pane.
+        """Capture text from pane.
 
         ``$ tmux capture-pane`` to pane.
         ``$ tmux capture-pane -S -10`` to pane.
@@ -244,19 +245,22 @@ class Pane(Obj):
 
     @overload
     def display_message(
-        self, cmd: str, get_text: "Literal[True]"
+        self,
+        cmd: str,
+        get_text: "t.Literal[True]",
     ) -> t.Union[str, t.List[str]]:
         ...
 
     @overload
-    def display_message(self, cmd: str, get_text: "Literal[False]") -> None:
+    def display_message(self, cmd: str, get_text: "t.Literal[False]") -> None:
         ...
 
     def display_message(
-        self, cmd: str, get_text: bool = False
+        self,
+        cmd: str,
+        get_text: bool = False,
     ) -> t.Optional[t.Union[str, t.List[str]]]:
-        """
-        ``$ tmux display-message`` to the pane.
+        """Display message to pane.
 
         Displays a message in target-client status line.
 
@@ -274,14 +278,15 @@ class Pane(Obj):
         self.cmd("display-message", cmd)
         return None
 
-    #
-    #
-    # These are commands that climb to the parent scope's methods with
-    # additional scoped window info.
-    #
+    """
+    Commands ("climber"-helpers)
+
+    These are commands that climb to the parent scope's methods with
+    additional scoped window info.
+    """
+
     def select_pane(self) -> "Pane":
-        """
-        Select pane. Return ``self``.
+        """Select pane.
 
         To select a window object asynchrously. If a ``pane`` object exists
         and is no longer longer the current window, ``w.select_pane()``
@@ -300,8 +305,7 @@ class Pane(Obj):
         start_directory: t.Optional[str] = None,
         percent: t.Optional[int] = None,
     ) -> "Pane":  # New Pane, not self
-        """
-        Split window at pane and return newly created :class:`Pane`.
+        """Split window at pane and return newly created :class:`Pane`.
 
         Parameters
         ----------
@@ -322,11 +326,12 @@ class Pane(Obj):
             percent=percent,
         )
 
-    #
-    #
+    """
+    Commands (helpers)
+    """
+
     def set_width(self, width: int) -> "Pane":
-        """
-        Set width of pane.
+        """Set pane width.
 
         Parameters
         ----------
@@ -337,8 +342,7 @@ class Pane(Obj):
         return self
 
     def set_height(self, height: int) -> "Pane":
-        """
-        Set height of pane.
+        """Set pane height.
 
         Parameters
         ----------
@@ -349,8 +353,7 @@ class Pane(Obj):
         return self
 
     def enter(self) -> "Pane":
-        """
-        Send carriage return to pane.
+        """Send carriage return to pane.
 
         ``$ tmux send-keys`` send Enter to the pane.
         """
@@ -364,7 +367,6 @@ class Pane(Obj):
 
     def reset(self) -> "Pane":
         """Reset and clear pane history."""
-
         self.cmd("send-keys", r"-R \; clear-history")
         return self
 
@@ -372,10 +374,13 @@ class Pane(Obj):
     # Dunder
     #
     def __eq__(self, other: object) -> bool:
-        assert isinstance(other, Pane)
-        return self.pane_id == other.pane_id
+        """Equal operator for :class:`Pane` object."""
+        if isinstance(other, Pane):
+            return self.pane_id == other.pane_id
+        return False
 
     def __repr__(self) -> str:
+        """Representation of :class:`Pane` object."""
         return f"{self.__class__.__name__}({self.pane_id} {self.window})"
 
     #
@@ -383,7 +388,7 @@ class Pane(Obj):
     #
     @property
     def id(self) -> t.Optional[str]:
-        """Alias of :attr:`Pane.pane_id`
+        """Alias of :attr:`Pane.pane_id`.
 
         >>> pane.id
         '%1'
@@ -395,7 +400,7 @@ class Pane(Obj):
 
     @property
     def index(self) -> t.Optional[str]:
-        """Alias of :attr:`Pane.pane_index`
+        """Alias of :attr:`Pane.pane_index`.
 
         >>> pane.index
         '0'
@@ -407,7 +412,7 @@ class Pane(Obj):
 
     @property
     def height(self) -> t.Optional[str]:
-        """Alias of :attr:`Pane.pane_height`
+        """Alias of :attr:`Pane.pane_height`.
 
         >>> pane.height.isdigit()
         True
@@ -419,7 +424,7 @@ class Pane(Obj):
 
     @property
     def width(self) -> t.Optional[str]:
-        """Alias of :attr:`Pane.pane_width`
+        """Alias of :attr:`Pane.pane_width`.
 
         >>> pane.width.isdigit()
         True
@@ -430,18 +435,28 @@ class Pane(Obj):
         return self.pane_width
 
     #
-    # Legacy
+    # Legacy: Redundant stuff we want to remove
     #
     def get(self, key: str, default: t.Optional[t.Any] = None) -> t.Any:
-        """
+        """Return key-based lookup. Deprecated by attributes.
+
         .. deprecated:: 0.16
+
+           Deprecated by attribute lookup.e.g. ``pane['window_name']`` is now
+           accessed via ``pane.window_name``.
+
         """
         warnings.warn("Pane.get() is deprecated", stacklevel=2)
         return getattr(self, key, default)
 
     def __getitem__(self, key: str) -> t.Any:
-        """
+        """Return item lookup by key. Deprecated in favor of attributes.
+
         .. deprecated:: 0.16
+
+           Deprecated in favor of attributes. e.g. ``pane['window_name']`` is now
+           accessed via ``pane.window_name``.
+
         """
         warnings.warn(f"Item lookups, e.g. pane['{key}'] is deprecated", stacklevel=2)
         return getattr(self, key)
