@@ -29,8 +29,7 @@ logger = logging.getLogger(__name__)
 
 @dataclasses.dataclass()
 class Window(Obj):
-    """
-    A :term:`tmux(1)` :term:`Window` [window_manual]_.
+    """:term:`tmux(1)` :term:`Window` [window_manual]_.
 
     Holds :class:`Pane` objects.
 
@@ -80,6 +79,7 @@ class Window(Obj):
     server: "Server"
 
     def refresh(self) -> None:
+        """Refresh window attributes from tmux."""
         assert isinstance(self.window_id, str)
         return super()._refresh(
             obj_key="window_id",
@@ -89,6 +89,7 @@ class Window(Obj):
 
     @classmethod
     def from_window_id(cls, server: "Server", window_id: str) -> "Window":
+        """Create Window from existing window_id."""
         window = fetch_obj(
             obj_key="window_id",
             obj_id=window_id,
@@ -100,14 +101,15 @@ class Window(Obj):
 
     @property
     def session(self) -> "Session":
+        """Parent session of window."""
         assert isinstance(self.session_id, str)
         from libtmux.session import Session
 
         return Session.from_session_id(server=self.server, session_id=self.session_id)
 
     @property
-    def panes(self) -> QueryList["Pane"]:  # type: ignore
-        """Panes belonging windows.
+    def panes(self) -> QueryList["Pane"]:
+        """Panes contained by window.
 
         Can be accessed via
         :meth:`.panes.get() <libtmux._internal.query_list.QueryList.get()>` and
@@ -130,7 +132,7 @@ class Window(Obj):
     """
 
     def cmd(self, cmd: str, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """Return :meth:`Server.cmd` defaulting to ``target_window`` as target.
+        """Execute tmux subcommand against target window. See :meth:`Server.cmd`.
 
         Send command to tmux with :attr:`window_id` as ``target-window``.
 
@@ -147,8 +149,9 @@ class Window(Obj):
     """
 
     def select_pane(self, target_pane: t.Union[str, int]) -> t.Optional["Pane"]:
-        """
-        Return selected :class:`Pane` through ``$ tmux select-pane``.
+        """Select pane and return selected :class:`Pane`.
+
+        ``$ tmux select-pane``.
 
         Parameters
         ----------
@@ -159,7 +162,6 @@ class Window(Obj):
         ------
         :class:`Pane`
         """
-
         if target_pane in ["-l", "-U", "-D", "-L", "-R"]:
             proc = self.cmd("select-pane", "-t%s" % self.window_id, target_pane)
         else:
@@ -180,8 +182,7 @@ class Window(Obj):
         percent: t.Optional[int] = None,
         environment: t.Optional[t.Dict[str, str]] = None,
     ) -> "Pane":
-        """
-        Split window and return the created :class:`Pane`.
+        """Split window and return the created :class:`Pane`.
 
         Used for splitting window and holding in a python object.
 
@@ -210,7 +211,6 @@ class Window(Obj):
 
         Notes
         -----
-
         :term:`tmux(1)` will move window to the new pane if the
         ``split-window`` target is off screen. tmux handles the ``-d`` the
         same way as ``new-window`` and ``attach`` in
@@ -258,7 +258,7 @@ class Window(Obj):
                     tmux_args += (f"-e{k}={v}",)
             else:
                 logger.warning(
-                    "Cannot set up environment as tmux 3.0 or newer is required."
+                    "Cannot set up environment as tmux 3.0 or newer is required.",
                 )
 
         if shell:
@@ -284,7 +284,9 @@ class Window(Obj):
         return self.select_pane("-l")
 
     def select_layout(self, layout: t.Optional[str] = None) -> "Window":
-        """Wrapper for ``$ tmux select-layout <layout>``.
+        """Select layout for window.
+
+        Wrapper for ``$ tmux select-layout <layout>``.
 
         Parameters
         ----------
@@ -325,8 +327,9 @@ class Window(Obj):
         return self
 
     def set_window_option(self, option: str, value: t.Union[int, str]) -> "Window":
-        """
-        Wrapper for ``$ tmux set-window-option <option> <value>``.
+        """Set option for tmux window.
+
+        Wraps ``$ tmux set-window-option <option> <value>``.
 
         Parameters
         ----------
@@ -359,11 +362,7 @@ class Window(Obj):
         return self
 
     def show_window_options(self, g: t.Optional[bool] = False) -> "WindowOptionDict":
-        """
-        Return a dict of options for the window.
-
-        For familiarity with tmux, the option ``option`` param forwards to
-        pick a single option, forwarding to :meth:`Window.show_window_option`.
+        """Return dict of options for window.
 
         .. versionchanged:: 0.13.0
 
@@ -400,10 +399,11 @@ class Window(Obj):
         return window_options
 
     def show_window_option(
-        self, option: str, g: bool = False
+        self,
+        option: str,
+        g: bool = False,
     ) -> t.Optional[t.Union[str, int]]:
-        """
-        Return a list of options for the window.
+        """Return option value for the target window.
 
         todo: test and return True/False for on/off string
 
@@ -444,8 +444,7 @@ class Window(Obj):
         return value
 
     def rename_window(self, new_name: str) -> "Window":
-        """
-        Return :class:`Window` object ``$ tmux rename-window <new_name>``.
+        """Rename window.
 
         Parameters
         ----------
@@ -454,7 +453,6 @@ class Window(Obj):
 
         Examples
         --------
-
         >>> window = session.attached_window
 
         >>> window.rename_window('My project')
@@ -463,7 +461,6 @@ class Window(Obj):
         >>> window.rename_window('New name')
         Window(@1 1:New name, Session($1 ...))
         """
-
         import shlex
 
         lex = shlex.shlex(new_name)
@@ -482,7 +479,6 @@ class Window(Obj):
 
     def kill_window(self) -> None:
         """Kill the current :class:`Window` object. ``$ tmux kill-window``."""
-
         proc = self.cmd(
             "kill-window",
             f"-t{self.session_id}:{self.window_index}",
@@ -492,10 +488,11 @@ class Window(Obj):
             raise exc.LibTmuxException(proc.stderr)
 
     def move_window(
-        self, destination: str = "", session: t.Optional[str] = None
+        self,
+        destination: str = "",
+        session: t.Optional[str] = None,
     ) -> "Window":
-        """
-        Move the current :class:`Window` object ``$ tmux move-window``.
+        """Move current :class:`Window` object ``$ tmux move-window``.
 
         Parameters
         ----------
@@ -527,8 +524,7 @@ class Window(Obj):
     # Climbers
     #
     def select_window(self) -> "Window":
-        """
-        Select window. Return ``self``.
+        """Select window.
 
         To select a window object asynchrously. If a ``window`` object exists
         and is no longer longer the current window, ``w.select_window()``
@@ -542,7 +538,7 @@ class Window(Obj):
     #
     @property
     def attached_pane(self) -> t.Optional["Pane"]:
-        """Return the attached :class:`Pane`."""
+        """Return attached :class:`Pane`."""
         for pane in self.panes:
             if pane.pane_active == "1":
                 return pane
@@ -552,10 +548,13 @@ class Window(Obj):
     # Dunder
     #
     def __eq__(self, other: object) -> bool:
-        assert isinstance(other, Window)
-        return self.window_id == other.window_id
+        """Equal operator for :class:`Window` object."""
+        if isinstance(other, Window):
+            return self.window_id == other.window_id
+        return False
 
     def __repr__(self) -> str:
+        """Representation of :class:`Window` object."""
         return "{}({} {}:{}, {})".format(
             self.__class__.__name__,
             self.window_id,
@@ -569,7 +568,7 @@ class Window(Obj):
     #
     @property
     def id(self) -> t.Optional[str]:
-        """Alias of :attr:`Window.window_id`
+        """Alias of :attr:`Window.window_id`.
 
         >>> window.id
         '@1'
@@ -581,7 +580,7 @@ class Window(Obj):
 
     @property
     def name(self) -> t.Optional[str]:
-        """Alias of :attr:`Window.window_name`
+        """Alias of :attr:`Window.window_name`.
 
         >>> window.name
         '...'
@@ -593,7 +592,7 @@ class Window(Obj):
 
     @property
     def index(self) -> t.Optional[str]:
-        """Alias of :attr:`Window.window_index`
+        """Alias of :attr:`Window.window_index`.
 
         >>> window.index
         '1'
@@ -605,7 +604,7 @@ class Window(Obj):
 
     @property
     def height(self) -> t.Optional[str]:
-        """Alias of :attr:`Window.window_height`
+        """Alias of :attr:`Window.window_height`.
 
         >>> window.height.isdigit()
         True
@@ -617,7 +616,7 @@ class Window(Obj):
 
     @property
     def width(self) -> t.Optional[str]:
-        """Alias of :attr:`Window.window_width`
+        """Alias of :attr:`Window.window_width`.
 
         >>> window.width.isdigit()
         True
@@ -631,29 +630,47 @@ class Window(Obj):
     # Legacy: Redundant stuff we want to remove
     #
     def get(self, key: str, default: t.Optional[t.Any] = None) -> t.Any:
-        """
+        """Return key-based lookup. Deprecated by attributes.
+
         .. deprecated:: 0.16
+
+           Deprecated by attribute lookup.e.g. ``window['window_name']`` is now
+           accessed via ``window.window_name``.
+
         """
         warnings.warn("Window.get() is deprecated", stacklevel=2)
         return getattr(self, key, default)
 
     def __getitem__(self, key: str) -> t.Any:
-        """
+        """Return item lookup by key. Deprecated in favor of attributes.
+
         .. deprecated:: 0.16
+
+           Deprecated in favor of attributes. e.g. ``window['window_name']`` is now
+           accessed via ``window.window_name``.
+
         """
         warnings.warn(f"Item lookups, e.g. window['{key}'] is deprecated", stacklevel=2)
         return getattr(self, key)
 
-    def get_by_id(self, id: str) -> t.Optional[Pane]:
-        """
+    def get_by_id(self, pane_id: str) -> t.Optional[Pane]:
+        """Return pane by id. Deprecated in favor of :meth:`.panes.get()`.
+
         .. deprecated:: 0.16
+
+           Deprecated by :meth:`.panes.get()`.
+
         """
         warnings.warn("Window.get_by_id() is deprecated", stacklevel=2)
-        return self.panes.get(pane_id=id, default=None)
+        return self.panes.get(pane_id=pane_id, default=None)
 
     def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Pane]:
-        """
+        """Filter through panes, return list of :class:`Pane`.
+
         .. deprecated:: 0.16
+
+           Deprecated by :meth:`.panes.filter()`.
+
         """
         warnings.warn("Window.where() is deprecated", stacklevel=2)
         try:
@@ -662,15 +679,23 @@ class Window(Obj):
             return []
 
     def find_where(self, kwargs: t.Dict[str, t.Any]) -> t.Optional[Pane]:
-        """
+        """Filter through panes, return first :class:`Pane`.
+
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :meth:`.panes.get()`.
+
         """
         warnings.warn("Window.find_where() is deprecated", stacklevel=2)
         return self.panes.get(default=None, **kwargs)
 
     def _list_panes(self) -> t.List[PaneDict]:
-        """
+        """Return list of panes (deprecated in favor of :meth:`.panes`).
+
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.panes`.
+
         """
         warnings.warn("Window._list_panes() is deprecated", stacklevel=2)
         return [pane.__dict__ for pane in self.panes]
@@ -680,6 +705,9 @@ class Window(Obj):
         """Property / alias to return :meth:`~._list_panes`.
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.panes`.
+
         """
         warnings.warn("_panes is deprecated", stacklevel=2)
         return self._list_panes()
@@ -688,15 +716,21 @@ class Window(Obj):
         """Return list of :class:`Pane` for the window.
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.panes`.
+
         """
         warnings.warn("list_panes() is deprecated", stacklevel=2)
         return self.panes
 
     @property
-    def children(self) -> QueryList["Pane"]:  # type:ignore
-        """Was used by TmuxRelationalObject (but that's longer used in this class)
+    def children(self) -> QueryList["Pane"]:
+        """Was used by TmuxRelationalObject (but that's longer used in this class).
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.panes`.
+
         """
         warnings.warn("Server.children is deprecated", stacklevel=2)
         return self.panes
